@@ -68,6 +68,8 @@ def _simplify_atans(exprn):
     return res
 
 def _termwise_trigsimp(exprn):
+    if not hasattr(exprn,'args'):
+        return exprn
     if len(exprn.args)==0:
         return exprn
     return exprn.func(*[trigsimp(a) for a in exprn.args])
@@ -529,7 +531,7 @@ class CanonicalTransformation():
         indices : array-list
             List of integer indices of the coordinate-momentum pairs to be
             transformed.
-        polar_symbol_pairs : list, optional
+        cartesian_symbol_pairs : list, optional
             List of symbols to use for the new cartesian-style variables.
             Default symbols are :math:`(y_i,x_i)` where the index i ranges
             over the number of variable pairs being transformed.
@@ -662,7 +664,7 @@ class CanonicalTransformation():
             \begin{pmatrix}
             \lambda_1 \\ \vdots \\ \lambda_N \\
             \gamma_1 \\ \vdots \\ \gamma_N \\
-            \Omega_1 \\ \vdots \\ \Omega_N
+            q_1 \\ \vdots \\ q_N
             \end{pmatrix}~.
 
         Arguments
@@ -673,6 +675,13 @@ class CanonicalTransformation():
         Tmtrx : ndarray, shape (N,N)
             An invertible matrix determining the new canonical angle variables
             as linear combinations of the planets' orbital elements.
+        new_qp_pairs : list, optional
+            A list of the symbols to use for the newly-generated
+            coordinate-momentum pairs. List entries should be given in the form
+            of 2-tuples containing a coordinate symbol followed by its
+            conjugate momentum variable. If no list is supplied, the default
+            symbols :math:`(Q_i,P_i)` will be used.
+
         Returns
         -------
         .CanonicalTransformation
