@@ -1,14 +1,21 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import division, print_function
-
-__all__ = ["get_compile_args", "get_cache_version", "get_header_dirs"]
-
 import sys
 import pkg_resources
+import os
+from ctypes import cdll, c_char_p
+import sysconfig
 
+suffix = sysconfig.get_config_var('EXT_SUFFIX')
+if suffix is None:
+    suffix = ".so"
 
-from ..celmech_version import __version__
+pymodulepath = os.path.dirname(__file__)
+clibcelmech = cdll.LoadLibrary(pymodulepath+"/../../libcelmech"+suffix)
+
+# Version
+__version__ = c_char_p.in_dll(clibcelmech, "celmech_version_str").value.decode('ascii')
 
 def get_compile_args(compiler):
     opts = ["-std=c++11", "-O2", "-DNDEBUG"]
@@ -26,3 +33,6 @@ def get_cache_version():
 def get_header_dirs():
     dirs = [pkg_resources.resource_filename(__name__, "lib/include")]
     return dirs
+
+__all__ = ["get_compile_args", "get_cache_version", "get_header_dirs"]
+
